==> estateplat-common-1.2.4-20200317.025316-276-sources.jar: cn/gtmap/estateplat/model/acceptance/YcslCmrxwsx.java <==
package cn.gtmap.estateplat.model.acceptance;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;

/**
 * @author <a href="mailto:xusong@gtmap.cn">xusong</a>
 * @version 1.0, 2019-11-26
 * @description: 一窗受理出卖人询问事项
 */
@Entity
@Table( name ="YCSL_CMRXWSX" )
public class YcslCmrxwsx implements Serializable {

    private static final long serialVersionUID = -1795545161825862059L;
    /**
     * 项目id
     */
    @Column(name = "CMRXWSXID")
    @Id
    private String cmrxwsxid;
    /**
     * 项目id
     */
    @Column(name = "PROID")
    private String proid;
    /**
     * 附属建筑物产证号
     */
    @Column(name = "FSJZWCZH")
    private String fsjzwczh;
    /**
     * 是否满五唯一
     */
    @Column(name = "SFMWWY")
    private Integer sfmwwy;
    /**
     * 是否购买满2年（包含2年）
     */
    @Column(name = "SFGMMLN")
    private Integer sfgmmln;
    /**
     * 是否直系亲属间交易
     */
    @Column(name = "SFZXQSJJY")
    private Integer sfzxqsjjy;

    /**
     * 是否有单独产权证的附属建筑物一并转让
     */
    @Column(name = "SFYDDCQZFSJZWYBZR")
    private Integer sfyddcqzfsjzwybzr;


    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getFsjzwczh() {
        return fsjzwczh;
    }

    public void setFsjzwczh(String fsjzwczh) {
        this.fsjzwczh = fsjzwczh;
    }

    public Integer getSfmwwy() {
        return sfmwwy;
    }

    public void setSfmwwy(Integer sfmwwy) {
        this.sfmwwy = sfmwwy;
    }

    public Integer getSfgmmln() {
        return sfgmmln;
    }

    public void setSfgmmln(Integer sfgmmln) {
        this.sfgmmln = sfgmmln;
    }

    public Integer getSfzxqsjjy() {
        return sfzxqsjjy;
    }

    public void setSfzxqsjjy(Integer sfzxqsjjy) {
        this.sfzxqsjjy = sfzxqsjjy;
    }

    public String getCmrxwsxid() {
        return cmrxwsxid;
    }

    public void setCmrxwsxid(String cmrxwsxid) {
        this.cmrxwsxid = cmrxwsxid;
    }

    public Integer getSfyddcqzfsjzwybzr() {
        return sfyddcqzfsjzwybzr;
    }

    public void setSfyddcqzfsjzwybzr(Integer sfyddcqzfsjzwybzr) {
        this.sfyddcqzfsjzwybzr = sfyddcqzfsjzwybzr;
    }
}

==> estateplat-common-1.2.4-20201125.025652-547-sources.jar: cn/gtmap/estateplat/model/acceptance/YcslCmrxwsx.java <==
package cn.gtmap.estateplat.model.acceptance;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;

/**
 * @author <a href="mailto:xusong@gtmap.cn">xusong</a>
 * @version 1.0, 2019-11-26
 * @description: 一窗受理出卖人询问事项
 */
@Entity
@Table( name ="YCSL_CMRXWSX" )
public class YcslCmrxwsx implements Serializable {

    private static final long serialVersionUID = -1795545161825862059L;
    /**
     * 项目id
     */
    @Column(name = "CMRXWSXID")
    @Id
    private String cmrxwsxid;
    /**
     * 项目id
     */
    @Column(name = "PROID")
    private String proid;
    /**
     * 附属建筑物产证号
     */
    @Column(name = "FSJZWCZH")
    private String fsjzwczh;
    /**
     * 是否满五唯一
     */
    @Column(name = "SFMWWY")
    private Integer sfmwwy;
    /**
     * 是否购买满2年（包含2年）
     */
    @Column(name = "SFGMMLN")
    private Integer sfgmmln;
    /**
     * 是否直系亲属间交易
     */
    @Column(name = "SFZXQSJJY")
    private Integer sfzxqsjjy;

    /**
     * 是否有单独产权证的附属建筑物一并转让
     */
    @Column(name = "SFYDDCQZFSJZWYBZR")
    private Integer sfyddcqzfsjzwybzr;

    /**
     * 是否自行成交
     */
    @Column(name = "SFZXCJ")
    private Integer sfzxcj;


    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getFsjzwczh() {
        return fsjzwczh;
    }

    public void setFsjzwczh(String fsjzwczh) {
        this.fsjzwczh = fsjzwczh;
    }

    public Integer getSfmwwy() {
        return sfmwwy;
    }

    public void setSfmwwy(Integer sfmwwy) {
        this.sfmwwy = sfmwwy;
    }

    public Integer getSfgmmln() {
        return sfgmmln;
    }

    public void setSfgmmln(Integer sfgmmln) {
        this.sfgmmln = sfgmmln;
    }

    public Integer getSfzxqsjjy() {
        return sfzxqsjjy;
    }

    public void setSfzxqsjjy(Integer sfzxqsjjy) {
        this.sfzxqsjjy = sfzxqsjjy;
    }

    public String getCmrxwsxid() {
        return cmrxwsxid;
    }

    public void setCmrxwsxid(String cmrxwsxid) {
        this.cmrxwsxid = cmrxwsxid;
    }

    public Integer getSfyddcqzfsjzwybzr() {
        return sfyddcqzfsjzwybzr;
    }

    public void setSfyddcqzfsjzwybzr(Integer sfyddcqzfsjzwybzr) {
        this.sfyddcqzfsjzwybzr = sfyddcqzfsjzwybzr;
    }

    public Integer getSfzxcj() {
        return sfzxcj;
    }

    public void setSfzxcj(Integer sfzxcj) {
        this.sfzxcj = sfzxcj;
    }
}
